"""
启动模块化程序的脚本。

该脚本允许通过 `python -m` 模块化调用程序。
"""

from .main import app

# 通过指定 prog_name 参数来设置程序的名称，
# 这有助于生成更清晰、更专业的帮助信息和命令行提示。
app(prog_name="gromacs-helix")

# 区别：
# 默认用法提示 `python -m gromacs_helix [OPTIONS] COMMAND [ARGS]...`
# 优化后用法提示 `gromacs-helix [OPTIONS] COMMAND [ARGS]...`



import typer


app = typer.Typer()


# 不给help参数时下面被装饰函数的注释会出现在help
@app.callback(invoke_without_command=True, help="A simple CLI tool for GROMACS")
def callback(ctx: typer.Context):
    """
    Args:
        ctx (typer.Context): Typer上下文对象，包含命令行参数和其他上下文信息。
    Raises:
        typer.Exit: 当没有子命令被调用时，退出程序并显示帮助信息。
    """
    if ctx.invoked_subcommand is None:
        typer.echo(ctx.get_help())
        raise typer.Exit()  # 我们希望程序显示帮助信息并立即退出，而不是继续执行其他代码


@app.command()
def shoot():
    """
    Shoot the portal gun
    """
    typer.echo("Shooting portal gun")


@app.command()
def load():
    """
    Load the portal gun
    """
    typer.echo("Loading portal gun")
